<?php
/**
 * @copyright © TMS-Plugins. All rights reserved.
 * @licence   See LICENCE.md for license details.
 */

namespace AmeliaBooking\Infrastructure\WP\EventListeners\Booking\Appointment;

use AmeliaBooking\Application\Commands\CommandResult;
use AmeliaBooking\Application\Services\Notification\EmailNotificationService;
use AmeliaBooking\Application\Services\Notification\SMSNotificationService;
use AmeliaBooking\Domain\Entity\Entities;
use AmeliaBooking\Domain\Factory\Booking\Appointment\AppointmentFactory;
use AmeliaBooking\Infrastructure\Common\Container;
use AmeliaBooking\Infrastructure\Services\Google\GoogleCalendarService;

/**
 * Class AppointmentEditedEventHandler
 *
 * @package AmeliaBooking\Infrastructure\WP\EventListeners\Booking\Appointment
 */
class AppointmentEditedEventHandler
{
    /** @var string */
    const APPOINTMENT_EDITED = 'appointmentEdited';

    /**
     * @param CommandResult $commandResult
     * @param Container     $container
     *
     * @throws \AmeliaBooking\Infrastructure\Common\Exceptions\NotFoundException
     * @throws \AmeliaBooking\Infrastructure\Common\Exceptions\QueryExecutionException
     * @throws \Interop\Container\Exception\ContainerException
     */
    public static function handle($commandResult, $container)
    {
        /** @var GoogleCalendarService $googleCalendarService */
        $googleCalendarService = $container->get('infrastructure.google.calendar.service');
        /** @var EmailNotificationService $emailNotificationService */
        $emailNotificationService = $container->get('application.emailNotification.service');
        /** @var SMSNotificationService $smsNotificationService */
        $smsNotificationService = $container->get('application.smsNotification.service');

        $appointment = $commandResult->getData()[Entities::APPOINTMENT];
        $bookings = $commandResult->getData()['bookingsWithChangedStatus'];
        $appointmentStatusChanged = $commandResult->getData()['appointmentStatusChanged'];
        $appointmentRescheduled = $commandResult->getData()['appointmentRescheduled'];

        try {
            $googleCalendarService->handleEvent(AppointmentFactory::create($appointment), self::APPOINTMENT_EDITED);
        } catch (\Exception $e) {
        }

        if ($appointmentStatusChanged === true) {
            $emailNotificationService->sendAppointmentStatusNotifications($appointment, true, true);

            $smsNotificationService->sendAppointmentStatusNotifications($appointment, true, true);
        }

        if ($appointmentRescheduled === true) {
            $emailNotificationService->sendAppointmentRescheduleNotifications($appointment);

            $smsNotificationService->sendAppointmentRescheduleNotifications($appointment);
        }

        $emailNotificationService->sendAppointmentEditedNotifications(
            $appointment,
            $bookings,
            $appointmentStatusChanged
        );

        $smsNotificationService->sendAppointmentEditedNotifications($appointment, $bookings, $appointmentStatusChanged);
    }
}
